@@ -1,23 +1,23 @@
-/* printif.h
+/*
+  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
+  Free Software Foundation, Inc.
 
-   Copyright (C) 2001, 2007 Free Software Foundation, Inc.
+  This file is part of GNU Inetutils.
 
-   Written by Marcus Brinkmann.
+  GNU Inetutils is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or (at
+  your option) any later version.
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License
-   as published by the Free Software Foundation; either version 3
-   of the License, or (at your option) any later version.
+  GNU Inetutils is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see `http://www.gnu.org/licenses/'. */
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02110-1301 USA. */
+/* Written by Marcus Brinkmann.  */
 
 #ifndef IFCONFIG_PRINTIF_H
 # define IFCONFIG_PRINTIF_H
@@ -34,7 +34,8 @@ extern int had_output;
 
 struct format_data
 {
-  const char *name;		/* Name of interface as specified on the command line.  */
+  const char *name;		/* Name of interface as specified on the
+				   command line.  */
   struct ifreq *ifr;
   int sfd;			/* Socket file descriptor to use.  */
   int first;			/* This is the first interface.  */
@@ -61,6 +62,7 @@ extern struct format_handle format_handles[];
 void put_char (format_data_t form, char c);
 void put_string (format_data_t form, const char *s);
 void put_int (format_data_t form, int argc, char *argv[], int nr);
+void put_ulong (format_data_t form, int argc, char *argv[], unsigned long val);
 void select_arg (format_data_t form, int argc, char *argv[], int nr);
 void put_addr (format_data_t form, int argc, char *argv[],
 	       struct sockaddr *sa);
@@ -99,6 +101,17 @@ void fh_mtu_query (format_data_t form, int argc, char *argv[]);
 void fh_mtu (format_data_t form, int argc, char *argv[]);
 void fh_metric_query (format_data_t form, int argc, char *argv[]);
 void fh_metric (format_data_t form, int argc, char *argv[]);
+void fh_map_query (format_data_t form, int argc, char *argv[]);
+void fh_irq_query (format_data_t form, int argc, char *argv[]);
+void fh_irq (format_data_t form, int argc, char *argv[]);
+void fh_baseaddr_query (format_data_t form, int argc, char *argv[]);
+void fh_baseaddr (format_data_t form, int argc, char *argv[]);
+void fh_memstart_query (format_data_t form, int argc, char *argv[]);
+void fh_memstart (format_data_t form, int argc, char *argv[]);
+void fh_memend_query (format_data_t form, int argc, char *argv[]);
+void fh_memend (format_data_t form, int argc, char *argv[]);
+void fh_dma_query (format_data_t form, int argc, char *argv[]);
+void fh_dma (format_data_t form, int argc, char *argv[]);
 
 /* Used for recursion by format handlers.  */
 void print_interfaceX (format_data_t form, int quiet);
